@@ -3,8 +3,8 @@ setClass(
          Class   = "LogitCap",
          contains="Logit",
          representation=representation(
-         mktSize               = "numeric",
-         capacities           = "numeric"
+         capacitiesPre           = "numeric",
+         capacitiesPost          = "numeric"
 
          ),
 
@@ -18,20 +18,28 @@ setClass(
              nprods <- length(object@shares)
 
 
-             if(nprods != length(object@capacities)){
-                 stop("'prices', 'capacities' must all be vectors with the same length")}
+             if(nprods != length(object@capacitiesPre)){
+                 stop("'shares', 'capacitiesPre' must all be vectors with the same length")}
+             if(length(object@capacitiesPost) != length(object@capacitiesPre)){
+               stop("'capacitiesPre', 'capacitiesPost', must be vectors with the same length")}
+             
 
-             if(any(is.na(object@capacities) |
-                    !is.finite(object@capacities) |
-                    object@capacities<0 ,na.rm=TRUE)){stop("'capacities' values must be positive, finite numbers")}
+             if(any(is.na(object@capacitiesPre) |
+                    #!is.finite(object@capacitiesPre) |
+                    object@capacitiesPre<0 ,na.rm=TRUE)){stop("'capacitiesPre' values must be positive numbers")}
 
-             if(length(object@mktSize)!=1 || isTRUE(object@mktSize<0)){stop("mktSize must be a positive number")}
 
-             if(any(object@mktSize*object@shares > object@capacities)){stop("utilization is greater than capacity")}
+             if(any(is.na(object@capacitiesPost) |
+                    #!is.finite(object@capacitiesPost) |
+                    object@capacitiesPost<0 ,na.rm=TRUE)){stop("'capacitiesPost' values must be positive numbers")}
+             
+             if(is.na(object@insideSize)){stop("'insideSize' must eqal the total pre-merger units sold in the market")}
+             
+             if(any(object@insideSize*object@shares > object@capacitiesPre)){warning("utilization is greater than capacity")}
 
-             if(identical(object@mktSize*object@shares,object@capacities)){stop("utilization cannot equal capacity for all products")}
+             if(identical(object@insideSize*object@shares,object@capacitiesPre)){warning("utilization equal capacity for all products")}
 
-             if(any(is.na(object@margins[object@mktSize*object@shares == object@capacities]))){
+             if(any(is.na(object@margins[object@insideSize*object@shares == object@capacitiesPre]))){
                  stop("'margins' cannot equal NA for capacity constrained products")
                  }
 
@@ -52,16 +60,18 @@ setMethod(
               shares       <-  object@shares
               margins      <-  object@margins
               prices       <-  object@prices
-              capacities  <-  object@capacities/object@mktSize
+              capacities  <-  object@capacitiesPre/object@insideSize
               idx          <-  object@normIndex
 
               if(is.na(idx)){
                   idxShare <- 1 - object@shareInside
                   idxPrice <- object@priceOutside
+                  
               }
               else{
                   idxShare <- shares[idx]
                   idxPrice <- prices[idx]
+                 
                }
 
               ## Uncover price coefficient and mean valuation from margins and revenue shares
@@ -100,23 +110,15 @@ setMethod(
               names(meanval)   <- object@labels
 
               object@slopes    <- list(alpha=minAlpha,meanval=meanval)
+              object@mktSize <- object@insideSize / sum(shares)
+              
 
 
               return(object)
           }
           )
 
-setMethod(
- f= "calcQuantities",
- signature= "LogitCap",
- definition=function(object,preMerger=TRUE){
 
-     quantities <- object@mktSize * calcShares(object,preMerger,revenue=FALSE)
-
-     return(quantities)
-
- }
-          )
 
 ## compute margins
 setMethod(
@@ -124,25 +126,28 @@ setMethod(
  signature= "LogitCap",
  definition=function(object,preMerger=TRUE){
 
+   margins <- object@margins #capacity-constrained margins not identified -- use supplied margins
 
      if( preMerger) {
-         margins <- object@margins #capacity-constrained margins not identified -- use supplied margins
-         constrained <- object@capacities == object@mktSize*object@shares
+       capacities <- object@capacitiesPre
+       
+     }
+    else{
+      
+      capacities <- object@capacitiesPost
+    }
+       
+         
+        
+         quantities <- calcQuantities(object, preMerger=TRUE)
+         constrained <-  abs(capacities - quantities) < 1e-5
 
          owner  <- object@ownerPre
          revenue<- calcShares(object,preMerger,revenue=TRUE)[!constrained]
          elast <-  elast(object,preMerger)
          margins[!constrained] <-  -1 * as.vector(MASS::ginv(t(elast*owner)[!constrained,!constrained]) %*% revenue) / revenue
 
-     }
-
-     else{
-         prices <- object@pricePost
-         mc     <- object@mcPost
-
-         margins <- 1 - mc/prices
-     }
-
+     
 
      names(margins) <- object@labels
 
@@ -159,15 +164,17 @@ setMethod(
  definition=function(object,preMerger=TRUE,isMax=FALSE,subset,...){
 
 
-     capacities <- object@capacities
+    
 
      if(preMerger){
        owner <- object@ownerPre
        mc    <- object@mcPre
+       capacities <- object@capacitiesPre
      }
      else{
        owner <- object@ownerPost
        mc    <- object@mcPost
+       capacities <- object@capacitiesPost
      }
 
      nprods <- length(object@shares)
@@ -195,14 +202,17 @@ setMethod(
 
 
          margins          <- 1 - mc/priceCand
-         quantities       <- calcQuantities(object,preMerger)[subset]
-         revenues         <- quantities * priceCand
+         revenues         <- calcShares(object, preMerger = preMerger, revenue = TRUE)
+         quantities       <- calcQuantities(object, preMerger = preMerger) 
+         revenues         <- revenues[subset]
          elasticities     <- elast(object,preMerger)[subset,subset]
 
          thisFOC <- revenues * diag(owner) + as.vector(t(elasticities * owner) %*% (margins * revenues))
-         constraint <- quantities - capacities
+         constraint <- ifelse(is.finite(capacities), (quantities - capacities) /object@insideSize, 0)
 
-         measure <- thisFOC + constraint + sqrt(thisFOC^2 + constraint^2)
+         
+         
+         measure <- ifelse( constraint != 0, thisFOC + constraint + sqrt(thisFOC^2 + constraint^2), thisFOC)
 
          return(measure)
      }
@@ -241,6 +251,7 @@ setMethod(
 
 
      mc       <- object@mcPre[prodIndex]
+     capacities <- object@capacitiesPre[prodIndex]
      pricePre <- object@pricePre
 
       FOC <- function(priceCand){
@@ -256,7 +267,7 @@ setMethod(
           elasticities     <- elast(object,preMerger=TRUE)[prodIndex,prodIndex]
 
           thisFOC <- revenues + as.vector(t(elasticities) %*% (margins * revenues))
-          constraint <- quantities - object@capacities[prodIndex]
+          constraint <- ifelse(!is.finite(capacities),0, quantities - capacities)
 
           measure <- thisFOC + constraint + sqrt(thisFOC^2 + constraint^2)
 
@@ -284,8 +295,9 @@ setMethod(
 
 logit.cap <- function(prices,shares,margins,
                       ownerPre,ownerPost,
-                      capacities,
-                      mktSize=sum(capacities),
+                      capacitiesPre = rep(Inf , length(prices)),
+                      capacitiesPost = capacitiesPre,
+                      insideSize,
                       normIndex=ifelse(sum(shares)<1,NA,1),
                       mcDelta=rep(0,length(prices)),
                       subset=rep(TRUE,length(prices)),
@@ -301,7 +313,10 @@ logit.cap <- function(prices,shares,margins,
 
     ## Create LogitCap  container to store relevant data
     result <- new("LogitCap",prices=prices, shares=shares,
-                  margins=margins,capacities=capacities, mktSize=mktSize,
+                  margins=margins,
+                  capacitiesPre=capacitiesPre,
+                  capacitiesPost=capacitiesPost, 
+                  insideSize=insideSize,
                   normIndex=normIndex,
                   ownerPre=ownerPre,
                   ownerPost=ownerPost,
@@ -317,7 +332,7 @@ logit.cap <- function(prices,shares,margins,
     if(!missing(control.equ)){
       result@control.equ <- control.equ
     }
-    
+     
     ## Convert ownership vectors to ownership matrices
     result@ownerPre  <- ownerToMatrix(result,TRUE)
     result@ownerPost <- ownerToMatrix(result,FALSE)
