@@ -111,6 +111,7 @@ pcaids <- function(shares,knownElast,mktElast=-1,
                    prices,diversions,
                    ownerPre,ownerPost,
                    knownElastIndex=1,
+                   insideSize = NA_real_,
                    mcDelta=rep(0, length(shares)),
                    subset=rep(TRUE, length(shares)),
                    priceStart=runif(length(shares)),
@@ -132,7 +133,7 @@ pcaids <- function(shares,knownElast,mktElast=-1,
   ## Create PCAIDS container to store relevant data
     result <- new("PCAIDS",shares=shares,prices=prices,
                    quantities=shares, margins=shares,mcDelta=mcDelta,
-                  subset=subset,
+                  subset=subset, insideSize = insideSize,
                   knownElast=knownElast,mktElast=mktElast,
                   ownerPre=ownerPre,ownerPost=ownerPost,
                   knownElastIndex=knownElastIndex,
